@@ -345,10 +345,8 @@ def echo_sql(func):
 
     def wrapper(self, *args, **kwargs):
         if options.echo_sql:
-            if len(args) > 1:
-                logging.info(f"SQL：{str(args[0])}；参数：{str(args[1:])}")
-            else:
-                logging.info(f"SQL：{str(args[0])}")
+            logging.info(f"echo_sql args:{args}")
+            logging.info(f"echo_sql kwargs:{kwargs}")
         return func(self, *args, **kwargs)
 
     return wrapper
